/**
 * @author SrinivasJasti
 * 
 */
package org.srinivas.siteworks;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.View;
import org.springframework.web.servlet.ViewResolver;
import org.springframework.web.servlet.view.BeanNameViewResolver;
import org.springframework.web.servlet.view.InternalResourceView;
import org.springframework.web.servlet.view.jasperreports.JasperReportsCsvView;
import org.springframework.web.servlet.view.jasperreports.JasperReportsHtmlView;
import org.springframework.web.servlet.view.jasperreports.JasperReportsPdfView;
import org.springframework.web.servlet.view.jasperreports.JasperReportsXlsView;


@Configuration
public class ViewConfiguration {

	public static final String REPORTCONTROLLER_JASPER_REPORT_DATASOURCE = "datasource";
	private static final String VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION = "classpath:jasper/SimpleJasperReport.jrxml";
	private static final Logger logger = LoggerFactory.getLogger(ViewConfiguration.class);

	/**
	 * Bean view resolver. 
	 * @return the view resolver
	 */
	@Bean
	public ViewResolver beanViewResolver() {
		BeanNameViewResolver viewResolver = new BeanNameViewResolver();
		viewResolver.setOrder(1);
		return viewResolver;
	}

	/**
	 * Jasperreport. 
	 * @return the InternalResourceView as View 
	 */
	@Bean
	public View jasperreport() {
		InternalResourceView view = new InternalResourceView();
		view.setUrl("/WEB-INF/displays/jasperreport.jsp");
		return view;
	}

	/**
	 * Pdf report. 
	 * @return JasperReportsPdfView as View
	 */
	@Bean
	public View pdfReport() {
		logger.info("ViewConfiguration pdfReport()");
		JasperReportsPdfView userReportPdfView = new JasperReportsPdfView();
		userReportPdfView.setUrl(VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION);
		logger.info("JRXML" + VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION);
		userReportPdfView.setReportDataKey(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE);
		return userReportPdfView;
	}

	/**
	 * Xls report. 
	 * @return the JasperReportsXlsView as View
	 */
	@Bean
	public View xlsReport() {
		logger.info("ViewConfiguration xlsReport()");
		JasperReportsXlsView userReportXlsView = new JasperReportsXlsView();
		userReportXlsView.setUrl(VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION);
		userReportXlsView.setReportDataKey(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE);
		return userReportXlsView;
	}

	/**
	 * Html report. 
	 * @return the JasperReportsHtmlView as View
	 */
	@Bean
	public View htmlReport() {
		logger.info("ViewConfiguration htmlReport()");
		JasperReportsHtmlView userReportHtmlView = new JasperReportsHtmlView();
		userReportHtmlView.setUrl(VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION);
		userReportHtmlView.setReportDataKey(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE);
		return userReportHtmlView;
	}

	/**
	 * Csv report. 
	 * @return the JasperReportsCsvView as View
	 */
	@Bean
	public View csvReport() {
		logger.info("ViewConfiguration csvReport()");
		JasperReportsCsvView userReportCsvView = new JasperReportsCsvView();
		userReportCsvView.setUrl(VIEWCONFIGURATION_JASPER_SIMPLE_JASPER_REPORT_JRXML_LOCATION);
		userReportCsvView.setReportDataKey(REPORTCONTROLLER_JASPER_REPORT_DATASOURCE);
		return userReportCsvView;
	}

}
